@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     ApiGatewayEndpointTypeType,
     ApplicationStateType,
@@ -104,86 +106,69 @@ __all__ = (
 ApiGatewayProxyConfigTypeDef = TypedDict(
     "ApiGatewayProxyConfigTypeDef",
     {
-        "ApiGatewayId": str,
-        "EndpointType": ApiGatewayEndpointTypeType,
-        "NlbArn": str,
-        "NlbName": str,
-        "ProxyUrl": str,
-        "StageName": str,
-        "VpcLinkId": str,
+        "ApiGatewayId": NotRequired[str],
+        "EndpointType": NotRequired[ApiGatewayEndpointTypeType],
+        "NlbArn": NotRequired[str],
+        "NlbName": NotRequired[str],
+        "ProxyUrl": NotRequired[str],
+        "StageName": NotRequired[str],
+        "VpcLinkId": NotRequired[str],
     },
-    total=False,
 )
 
 ApiGatewayProxyInputTypeDef = TypedDict(
     "ApiGatewayProxyInputTypeDef",
     {
-        "EndpointType": ApiGatewayEndpointTypeType,
-        "StageName": str,
+        "EndpointType": NotRequired[ApiGatewayEndpointTypeType],
+        "StageName": NotRequired[str],
     },
-    total=False,
 )
 
 ApiGatewayProxySummaryTypeDef = TypedDict(
     "ApiGatewayProxySummaryTypeDef",
     {
-        "ApiGatewayId": str,
-        "EndpointType": ApiGatewayEndpointTypeType,
-        "NlbArn": str,
-        "NlbName": str,
-        "ProxyUrl": str,
-        "StageName": str,
-        "VpcLinkId": str,
+        "ApiGatewayId": NotRequired[str],
+        "EndpointType": NotRequired[ApiGatewayEndpointTypeType],
+        "NlbArn": NotRequired[str],
+        "NlbName": NotRequired[str],
+        "ProxyUrl": NotRequired[str],
+        "StageName": NotRequired[str],
+        "VpcLinkId": NotRequired[str],
     },
-    total=False,
 )
 
 ApplicationSummaryTypeDef = TypedDict(
     "ApplicationSummaryTypeDef",
     {
-        "ApiGatewayProxy": "ApiGatewayProxySummaryTypeDef",
-        "ApplicationId": str,
-        "Arn": str,
-        "CreatedByAccountId": str,
-        "CreatedTime": datetime,
-        "EnvironmentId": str,
-        "Error": "ErrorResponseTypeDef",
-        "LastUpdatedTime": datetime,
-        "Name": str,
-        "OwnerAccountId": str,
-        "ProxyType": Literal["API_GATEWAY"],
-        "State": ApplicationStateType,
-        "Tags": Dict[str, str],
-        "VpcId": str,
+        "ApiGatewayProxy": NotRequired["ApiGatewayProxySummaryTypeDef"],
+        "ApplicationId": NotRequired[str],
+        "Arn": NotRequired[str],
+        "CreatedByAccountId": NotRequired[str],
+        "CreatedTime": NotRequired[datetime],
+        "EnvironmentId": NotRequired[str],
+        "Error": NotRequired["ErrorResponseTypeDef"],
+        "LastUpdatedTime": NotRequired[datetime],
+        "Name": NotRequired[str],
+        "OwnerAccountId": NotRequired[str],
+        "ProxyType": NotRequired[Literal["API_GATEWAY"]],
+        "State": NotRequired[ApplicationStateType],
+        "Tags": NotRequired[Dict[str, str]],
+        "VpcId": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateApplicationRequestRequestTypeDef",
+CreateApplicationRequestRequestTypeDef = TypedDict(
+    "CreateApplicationRequestRequestTypeDef",
     {
         "EnvironmentIdentifier": str,
         "Name": str,
         "ProxyType": Literal["API_GATEWAY"],
         "VpcId": str,
+        "ApiGatewayProxy": NotRequired["ApiGatewayProxyInputTypeDef"],
+        "ClientToken": NotRequired[str],
+        "Tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateApplicationRequestRequestTypeDef",
-    {
-        "ApiGatewayProxy": "ApiGatewayProxyInputTypeDef",
-        "ClientToken": str,
-        "Tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateApplicationRequestRequestTypeDef(
-    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
-):
-    pass
-
 
 CreateApplicationResponseTypeDef = TypedDict(
     "CreateApplicationResponseTypeDef",
@@ -205,29 +190,16 @@ CreateApplicationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateEnvironmentRequestRequestTypeDef",
+CreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "CreateEnvironmentRequestRequestTypeDef",
     {
         "Name": str,
         "NetworkFabricType": Literal["TRANSIT_GATEWAY"],
+        "ClientToken": NotRequired[str],
+        "Description": NotRequired[str],
+        "Tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateEnvironmentRequestRequestTypeDef",
-    {
-        "ClientToken": str,
-        "Description": str,
-        "Tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateEnvironmentRequestRequestTypeDef(
-    _RequiredCreateEnvironmentRequestRequestTypeDef, _OptionalCreateEnvironmentRequestRequestTypeDef
-):
-    pass
-
 
 CreateEnvironmentResponseTypeDef = TypedDict(
     "CreateEnvironmentResponseTypeDef",
@@ -246,31 +218,18 @@ CreateEnvironmentResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateRouteRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateRouteRequestRequestTypeDef",
+CreateRouteRequestRequestTypeDef = TypedDict(
+    "CreateRouteRequestRequestTypeDef",
     {
         "ApplicationIdentifier": str,
         "EnvironmentIdentifier": str,
         "RouteType": RouteTypeType,
         "ServiceIdentifier": str,
+        "ClientToken": NotRequired[str],
+        "Tags": NotRequired[Mapping[str, str]],
+        "UriPathRoute": NotRequired["UriPathRouteInputTypeDef"],
     },
 )
-_OptionalCreateRouteRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateRouteRequestRequestTypeDef",
-    {
-        "ClientToken": str,
-        "Tags": Mapping[str, str],
-        "UriPathRoute": "UriPathRouteInputTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateRouteRequestRequestTypeDef(
-    _RequiredCreateRouteRequestRequestTypeDef, _OptionalCreateRouteRequestRequestTypeDef
-):
-    pass
-
 
 CreateRouteResponseTypeDef = TypedDict(
     "CreateRouteResponseTypeDef",
@@ -291,34 +250,21 @@ CreateRouteResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateServiceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateServiceRequestRequestTypeDef",
+CreateServiceRequestRequestTypeDef = TypedDict(
+    "CreateServiceRequestRequestTypeDef",
     {
         "ApplicationIdentifier": str,
         "EndpointType": ServiceEndpointTypeType,
         "EnvironmentIdentifier": str,
         "Name": str,
+        "ClientToken": NotRequired[str],
+        "Description": NotRequired[str],
+        "LambdaEndpoint": NotRequired["LambdaEndpointInputTypeDef"],
+        "Tags": NotRequired[Mapping[str, str]],
+        "UrlEndpoint": NotRequired["UrlEndpointInputTypeDef"],
+        "VpcId": NotRequired[str],
     },
 )
-_OptionalCreateServiceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateServiceRequestRequestTypeDef",
-    {
-        "ClientToken": str,
-        "Description": str,
-        "LambdaEndpoint": "LambdaEndpointInputTypeDef",
-        "Tags": Mapping[str, str],
-        "UrlEndpoint": "UrlEndpointInputTypeDef",
-        "VpcId": str,
-    },
-    total=False,
-)
-
-
-class CreateServiceRequestRequestTypeDef(
-    _RequiredCreateServiceRequestRequestTypeDef, _OptionalCreateServiceRequestRequestTypeDef
-):
-    pass
-
 
 CreateServiceResponseTypeDef = TypedDict(
     "CreateServiceResponseTypeDef",
@@ -438,47 +384,44 @@ DeleteServiceResponseTypeDef = TypedDict(
 EnvironmentSummaryTypeDef = TypedDict(
     "EnvironmentSummaryTypeDef",
     {
-        "Arn": str,
-        "CreatedTime": datetime,
-        "Description": str,
-        "EnvironmentId": str,
-        "Error": "ErrorResponseTypeDef",
-        "LastUpdatedTime": datetime,
-        "Name": str,
-        "NetworkFabricType": Literal["TRANSIT_GATEWAY"],
-        "OwnerAccountId": str,
-        "State": EnvironmentStateType,
-        "Tags": Dict[str, str],
-        "TransitGatewayId": str,
+        "Arn": NotRequired[str],
+        "CreatedTime": NotRequired[datetime],
+        "Description": NotRequired[str],
+        "EnvironmentId": NotRequired[str],
+        "Error": NotRequired["ErrorResponseTypeDef"],
+        "LastUpdatedTime": NotRequired[datetime],
+        "Name": NotRequired[str],
+        "NetworkFabricType": NotRequired[Literal["TRANSIT_GATEWAY"]],
+        "OwnerAccountId": NotRequired[str],
+        "State": NotRequired[EnvironmentStateType],
+        "Tags": NotRequired[Dict[str, str]],
+        "TransitGatewayId": NotRequired[str],
     },
-    total=False,
 )
 
 EnvironmentVpcTypeDef = TypedDict(
     "EnvironmentVpcTypeDef",
     {
-        "AccountId": str,
-        "CidrBlocks": List[str],
-        "CreatedTime": datetime,
-        "EnvironmentId": str,
-        "LastUpdatedTime": datetime,
-        "VpcId": str,
-        "VpcName": str,
+        "AccountId": NotRequired[str],
+        "CidrBlocks": NotRequired[List[str]],
+        "CreatedTime": NotRequired[datetime],
+        "EnvironmentId": NotRequired[str],
+        "LastUpdatedTime": NotRequired[datetime],
+        "VpcId": NotRequired[str],
+        "VpcName": NotRequired[str],
     },
-    total=False,
 )
 
 ErrorResponseTypeDef = TypedDict(
     "ErrorResponseTypeDef",
     {
-        "AccountId": str,
-        "AdditionalDetails": Dict[str, str],
-        "Code": ErrorCodeType,
-        "Message": str,
-        "ResourceIdentifier": str,
-        "ResourceType": ErrorResourceTypeType,
+        "AccountId": NotRequired[str],
+        "AdditionalDetails": NotRequired[Dict[str, str]],
+        "Code": NotRequired[ErrorCodeType],
+        "Message": NotRequired[str],
+        "ResourceIdentifier": NotRequired[str],
+        "ResourceType": NotRequired[ErrorResourceTypeType],
     },
-    total=False,
 )
 
 GetApplicationRequestRequestTypeDef = TypedDict(
@@ -620,9 +563,8 @@ GetServiceResponseTypeDef = TypedDict(
 LambdaEndpointConfigTypeDef = TypedDict(
     "LambdaEndpointConfigTypeDef",
     {
-        "Arn": str,
+        "Arn": NotRequired[str],
     },
-    total=False,
 )
 
 LambdaEndpointInputTypeDef = TypedDict(
@@ -635,32 +577,18 @@ LambdaEndpointInputTypeDef = TypedDict(
 LambdaEndpointSummaryTypeDef = TypedDict(
     "LambdaEndpointSummaryTypeDef",
     {
-        "Arn": str,
+        "Arn": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredListApplicationsRequestRequestTypeDef = TypedDict(
-    "_RequiredListApplicationsRequestRequestTypeDef",
+ListApplicationsRequestRequestTypeDef = TypedDict(
+    "ListApplicationsRequestRequestTypeDef",
     {
         "EnvironmentIdentifier": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListApplicationsRequestRequestTypeDef = TypedDict(
-    "_OptionalListApplicationsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListApplicationsRequestRequestTypeDef(
-    _RequiredListApplicationsRequestRequestTypeDef, _OptionalListApplicationsRequestRequestTypeDef
-):
-    pass
-
 
 ListApplicationsResponseTypeDef = TypedDict(
     "ListApplicationsResponseTypeDef",
@@ -671,28 +599,14 @@ ListApplicationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListEnvironmentVpcsRequestRequestTypeDef = TypedDict(
-    "_RequiredListEnvironmentVpcsRequestRequestTypeDef",
+ListEnvironmentVpcsRequestRequestTypeDef = TypedDict(
+    "ListEnvironmentVpcsRequestRequestTypeDef",
     {
         "EnvironmentIdentifier": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListEnvironmentVpcsRequestRequestTypeDef = TypedDict(
-    "_OptionalListEnvironmentVpcsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListEnvironmentVpcsRequestRequestTypeDef(
-    _RequiredListEnvironmentVpcsRequestRequestTypeDef,
-    _OptionalListEnvironmentVpcsRequestRequestTypeDef,
-):
-    pass
-
 
 ListEnvironmentVpcsResponseTypeDef = TypedDict(
     "ListEnvironmentVpcsResponseTypeDef",
@@ -706,10 +620,9 @@ ListEnvironmentVpcsResponseTypeDef = TypedDict(
 ListEnvironmentsRequestRequestTypeDef = TypedDict(
     "ListEnvironmentsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListEnvironmentsResponseTypeDef = TypedDict(
@@ -721,28 +634,15 @@ ListEnvironmentsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRoutesRequestRequestTypeDef = TypedDict(
-    "_RequiredListRoutesRequestRequestTypeDef",
+ListRoutesRequestRequestTypeDef = TypedDict(
+    "ListRoutesRequestRequestTypeDef",
     {
         "ApplicationIdentifier": str,
         "EnvironmentIdentifier": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListRoutesRequestRequestTypeDef = TypedDict(
-    "_OptionalListRoutesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListRoutesRequestRequestTypeDef(
-    _RequiredListRoutesRequestRequestTypeDef, _OptionalListRoutesRequestRequestTypeDef
-):
-    pass
-
 
 ListRoutesResponseTypeDef = TypedDict(
     "ListRoutesResponseTypeDef",
@@ -753,28 +653,15 @@ ListRoutesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListServicesRequestRequestTypeDef = TypedDict(
-    "_RequiredListServicesRequestRequestTypeDef",
+ListServicesRequestRequestTypeDef = TypedDict(
+    "ListServicesRequestRequestTypeDef",
     {
         "ApplicationIdentifier": str,
         "EnvironmentIdentifier": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListServicesRequestRequestTypeDef = TypedDict(
-    "_OptionalListServicesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListServicesRequestRequestTypeDef(
-    _RequiredListServicesRequestRequestTypeDef, _OptionalListServicesRequestRequestTypeDef
-):
-    pass
-
 
 ListServicesResponseTypeDef = TypedDict(
     "ListServicesResponseTypeDef",
@@ -803,11 +690,10 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PutResourcePolicyRequestRequestTypeDef = TypedDict(
@@ -832,49 +718,47 @@ ResponseMetadataTypeDef = TypedDict(
 RouteSummaryTypeDef = TypedDict(
     "RouteSummaryTypeDef",
     {
-        "ApplicationId": str,
-        "Arn": str,
-        "CreatedByAccountId": str,
-        "CreatedTime": datetime,
-        "EnvironmentId": str,
-        "Error": "ErrorResponseTypeDef",
-        "IncludeChildPaths": bool,
-        "LastUpdatedTime": datetime,
-        "Methods": List[HttpMethodType],
-        "OwnerAccountId": str,
-        "PathResourceToId": Dict[str, str],
-        "RouteId": str,
-        "RouteType": RouteTypeType,
-        "ServiceId": str,
-        "SourcePath": str,
-        "State": RouteStateType,
-        "Tags": Dict[str, str],
+        "ApplicationId": NotRequired[str],
+        "Arn": NotRequired[str],
+        "CreatedByAccountId": NotRequired[str],
+        "CreatedTime": NotRequired[datetime],
+        "EnvironmentId": NotRequired[str],
+        "Error": NotRequired["ErrorResponseTypeDef"],
+        "IncludeChildPaths": NotRequired[bool],
+        "LastUpdatedTime": NotRequired[datetime],
+        "Methods": NotRequired[List[HttpMethodType]],
+        "OwnerAccountId": NotRequired[str],
+        "PathResourceToId": NotRequired[Dict[str, str]],
+        "RouteId": NotRequired[str],
+        "RouteType": NotRequired[RouteTypeType],
+        "ServiceId": NotRequired[str],
+        "SourcePath": NotRequired[str],
+        "State": NotRequired[RouteStateType],
+        "Tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
 ServiceSummaryTypeDef = TypedDict(
     "ServiceSummaryTypeDef",
     {
-        "ApplicationId": str,
-        "Arn": str,
-        "CreatedByAccountId": str,
-        "CreatedTime": datetime,
-        "Description": str,
-        "EndpointType": ServiceEndpointTypeType,
-        "EnvironmentId": str,
-        "Error": "ErrorResponseTypeDef",
-        "LambdaEndpoint": "LambdaEndpointSummaryTypeDef",
-        "LastUpdatedTime": datetime,
-        "Name": str,
-        "OwnerAccountId": str,
-        "ServiceId": str,
-        "State": ServiceStateType,
-        "Tags": Dict[str, str],
-        "UrlEndpoint": "UrlEndpointSummaryTypeDef",
-        "VpcId": str,
+        "ApplicationId": NotRequired[str],
+        "Arn": NotRequired[str],
+        "CreatedByAccountId": NotRequired[str],
+        "CreatedTime": NotRequired[datetime],
+        "Description": NotRequired[str],
+        "EndpointType": NotRequired[ServiceEndpointTypeType],
+        "EnvironmentId": NotRequired[str],
+        "Error": NotRequired["ErrorResponseTypeDef"],
+        "LambdaEndpoint": NotRequired["LambdaEndpointSummaryTypeDef"],
+        "LastUpdatedTime": NotRequired[datetime],
+        "Name": NotRequired[str],
+        "OwnerAccountId": NotRequired[str],
+        "ServiceId": NotRequired[str],
+        "State": NotRequired[ServiceStateType],
+        "Tags": NotRequired[Dict[str, str]],
+        "UrlEndpoint": NotRequired["UrlEndpointSummaryTypeDef"],
+        "VpcId": NotRequired[str],
     },
-    total=False,
 )
 
 TagResourceRequestRequestTypeDef = TypedDict(
@@ -893,62 +777,36 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUriPathRouteInputTypeDef = TypedDict(
-    "_RequiredUriPathRouteInputTypeDef",
+UriPathRouteInputTypeDef = TypedDict(
+    "UriPathRouteInputTypeDef",
     {
         "ActivationState": Literal["ACTIVE"],
         "SourcePath": str,
+        "IncludeChildPaths": NotRequired[bool],
+        "Methods": NotRequired[Sequence[HttpMethodType]],
     },
 )
-_OptionalUriPathRouteInputTypeDef = TypedDict(
-    "_OptionalUriPathRouteInputTypeDef",
-    {
-        "IncludeChildPaths": bool,
-        "Methods": Sequence[HttpMethodType],
-    },
-    total=False,
-)
-
-
-class UriPathRouteInputTypeDef(
-    _RequiredUriPathRouteInputTypeDef, _OptionalUriPathRouteInputTypeDef
-):
-    pass
-
 
 UrlEndpointConfigTypeDef = TypedDict(
     "UrlEndpointConfigTypeDef",
     {
-        "HealthUrl": str,
-        "Url": str,
+        "HealthUrl": NotRequired[str],
+        "Url": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredUrlEndpointInputTypeDef = TypedDict(
-    "_RequiredUrlEndpointInputTypeDef",
+UrlEndpointInputTypeDef = TypedDict(
+    "UrlEndpointInputTypeDef",
     {
         "Url": str,
+        "HealthUrl": NotRequired[str],
     },
 )
-_OptionalUrlEndpointInputTypeDef = TypedDict(
-    "_OptionalUrlEndpointInputTypeDef",
-    {
-        "HealthUrl": str,
-    },
-    total=False,
-)
-
-
-class UrlEndpointInputTypeDef(_RequiredUrlEndpointInputTypeDef, _OptionalUrlEndpointInputTypeDef):
-    pass
-
 
 UrlEndpointSummaryTypeDef = TypedDict(
     "UrlEndpointSummaryTypeDef",
     {
-        "HealthUrl": str,
-        "Url": str,
+        "HealthUrl": NotRequired[str],
+        "Url": NotRequired[str],
     },
-    total=False,
 )
